pub struct PartitionSpec { /* private fields */ }Expand description
Phase-1 partition specification for a context namespace.
This intentionally models only identity partition fields. More advanced
Lance partition transforms (bucket, truncate, time transforms) can be
layered in once the namespace resolver grows past the single-partition path.
Implementations
Sourceimpl PartitionSpec
impl PartitionSpec
Sourcepub fn new<I, S>(fields: I) -> Result<PartitionSpec, Error>
pub fn new<I, S>(fields: I) -> Result<PartitionSpec, Error>
Create a v1 identity partition spec from ordered field names.
Sourcepub fn with_version<I, S>(
version: i32,
fields: I,
) -> Result<PartitionSpec, Error>
pub fn with_version<I, S>( version: i32, fields: I, ) -> Result<PartitionSpec, Error>
Create an identity partition spec with an explicit version.
pub fn tenant() -> PartitionSpec
pub fn tenant_source() -> PartitionSpec
pub fn version(&self) -> i32
pub fn fields(&self) -> &[String]